Learn R Programming

pould (version 1.0.1)

extractLoci: Extract Locus Information from Supplied Haplotype Data

Description

This function extracts locus information from the haplotype data, and structures it for LDWrap().

Usage

extractLoci(dataSet)

Arguments

dataSet

Data frame of two haplotypes extracted from the famData provided to LDWrap()

Value

List of two vector elements; the locus prefix (if any), e.g. "HLA-", and the interleaved unsuffixed and suffixed locus names (e.g., locus, locus_1)

Examples

Run this code
# NOT RUN {
#
# }

Run the code above in your browser using DataLab