Learn R Programming

pould (version 1.0.1)

hla.hap.demo: Example Six-Locus HLA Haplotype Data in GL String Format

Description

A data frame of experimentally phased genotype data for the HLA-A, -C, -B, -DRB1, -DQB1 and DQB1 loci. These haplotypes are for 419 unrelated European American control subjects included in a study of Multiple Sclerosis. These haplotypes were experimentally phased using the EM algorithm; low-frequency haplotypes (with counts < 3) are assigned stochasically by the EM method, so the phase "quality" of these haplotypes should be considered lower than that for haplotypes determined via family segregation analysis.

Usage

data(hla.hap.demo)

Arguments

Format

A data frame with 419 rows and two columns

  • Relation: the genotyped individual's status in a family

  • Gl String: GL String formatted multilocus phased HLA genotype

References

  • Published study: Mack et al. Genes Immun. 2019;20(4):308-326. doi: 10.1038/s41435-017-0006-8.

  • GL String format: Milius et al. Tissue Antigens. 2013;82(2):106-12. doi: 10.1111/tan.12150.