A data frame of phased two-field HLA-DRB1 and HLA-DQB1 genotypes for 419 European American control subjects included in a study of Multiple Sclerosis. Genotype data for each locus is shown in two columns; the alleles in columns 1 and 2 are phased with the alleles in columns 3 and 4, respectively. These genotypes were extracted from the hla.hap.demo dataset.
data(drb1.dqb1.demo)A data frame with 419 rows and four columns
DRB1: the first of two two-field HLA-DRB1 alleles
DRB1: the second of two two-field HLA-DRB1 alleles
DQB1: the first of two two-field HLA-DQB1 alleles
DQB1: the second of two two-field HLA-DRB1 alleles
Mack et al. Genes Immun. 2019;20(4):308-326. doi: 10.1038/s41435-017-0006-8.