powered by
This function extracts locus information from the haplotype data, and structures it for LDWrap().
extractLoci(dataSet)
Data frame of two haplotypes extracted from the famData provided to LDWrap()
List of two vector elements; the locus prefix (if any), e.g. "HLA-", and the interleaved unsuffixed and suffixed locus names (e.g., locus, locus_1)
# NOT RUN { # # }
Run the code above in your browser using DataLab